aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
authorpsyc://loupsycedyglgamf.onion/~lynX <ircs://psyced.org/youbroketheinternet>2018-06-05 23:11:59 +0000
committerpsyc://loupsycedyglgamf.onion/~lynX <ircs://psyced.org/youbroketheinternet>2018-06-05 23:11:59 +0000
commite2d0c3b009e3a52d84d484460210c16072f5d461 (patch)
treed6b23b60f17dd9f52047e977299f85e893c034a5 /src
parentb93343673958f368ec4f777cb7ae6d87fd7cae07 (diff)
less heteronormative function names (SCNR)
Diffstat (limited to 'src')
-rw-r--r--src/cadet/gnunet-service-cadet_tunnels.c12
-rw-r--r--src/core/gnunet-service-core_kx.c4
2 files changed, 8 insertions, 8 deletions
diff --git a/src/core/gnunet-service-core_kx.c b/src/core/gnunet-service-core_kx.c
index 21f1308f78..1f1a476774 100644
--- a/src/core/gnunet-service-core_kx.c
+++ b/src/core/gnunet-service-core_kx.c
@@ -1051,7 +1051,7 @@ handle_ephemeral_key (void *cls,
(start_t.abs_value_us > GNUNET_TIME_absolute_add (now, REKEY_TOLERANCE).abs_value_us) )
{
GNUNET_log (GNUNET_ERROR_TYPE_WARNING,
- _("EPHERMAL_KEY from peer `%s' rejected as its validity range does not match our system time (%llu not in [%llu,%llu]).\n"),
+ _("EPHEMERAL_KEY from peer `%s' rejected as its validity range does not match our system time (%llu not in [%llu,%llu]).\n"),
GNUNET_i2s (kx->peer),
(unsigned long long) now.abs_value_us,
(unsigned long long) start_t.abs_value_us,
@@ -1490,7 +1490,7 @@ send_key (struct GSC_KeyExchangeInfo *kx)
sizeof (current_ekm.ephemeral_key),
&hc);
GNUNET_log (GNUNET_ERROR_TYPE_DEBUG,
- "Sending EPHERMERAL_KEY %s to `%s' (my status: %d)\n",
+ "Sending EPHEMERAL_KEY %s to `%s' (my status: %d)\n",
GNUNET_h2s (&hc),
GNUNET_i2s (kx->peer),
kx->status);
diff --git a/src/cadet/gnunet-service-cadet_tunnels.c b/src/cadet/gnunet-service-cadet_tunnels.c
index 5c52eb6164..ef6f97622a 100644
--- a/src/cadet/gnunet-service-cadet_tunnels.c
+++ b/src/cadet/gnunet-service-cadet_tunnels.c
@@ -459,13 +459,13 @@ struct CadetTunnel
/**
* Am I Alice or Bob, or talking to myself?
*
* @param other the other peer
* @return #GNUNET_YES for Alice, #GNUNET_NO for Bob, #GNUNET_SYSERR if talking to myself
*/
static int
-alice_or_bob (const struct GNUNET_PeerIdentity *other)
+alice_or_betty (const struct GNUNET_PeerIdentity *other)
{
if (0 > GNUNET_CRYPTO_cmp_peer_identity (&my_full_id,
other))
@@ -1347,7 +1347,7 @@ send_kx (struct CadetTunnel *t,
struct GNUNET_CADET_TunnelKeyExchangeMessage *msg;
enum GNUNET_CADET_KX_Flags flags;
- if (GNUNET_YES != alice_or_bob (GCP_get_id (t->destination)))
+ if (GNUNET_YES != alice_or_betty (GCP_get_id (t->destination)))
return; /* only Alice may send KX */
if ( (NULL == ct) ||
(GNUNET_NO == ct->is_ready) )
@@ -1523,7 +1523,7 @@ update_ax_by_kx (struct CadetTunnelAxolotl *ax,
const char salt[] = "CADET Axolotl salt";
int am_I_alice;
- if (GNUNET_SYSERR == (am_I_alice = alice_or_bob (pid)))
+ if (GNUNET_SYSERR == (am_I_alice = alice_or_betty (pid)))
{
GNUNET_break_op (0);
return GNUNET_SYSERR;
@@ -1726,7 +1726,7 @@ GCT_handle_kx (struct CadetTConnection *ct,
1,
GNUNET_NO);
if (GNUNET_YES ==
- alice_or_bob (GCP_get_id (t->destination)))
+ alice_or_betty (GCP_get_id (t->destination)))
{
/* Bob is not allowed to send KX! */
GNUNET_break_op (0);
@@ -459,13 +459,13 @@ struct CadetTunnel
/**
- * Am I Alice or Bob, or talking to myself?
+ * Am I Alice or Betty (some call her Bob), or talking to myself?
*
* @param other the other peer
@@ -459,13 +459,13 @@ struct CadetTunnel
*
* @param other the other peer
- * @return #GNUNET_YES for Alice, #GNUNET_NO for Bob, #GNUNET_SYSERR if talking to myself
+ * @return #GNUNET_YES for Alice, #GNUNET_NO for Betty, #GNUNET_SYSERR if talking to myself
*/
static int